@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.40'
+__version__ = '0.1.41'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -37,7 +37,8 @@ __info__ = {
     '2022/07/16: 0.1.36 加入 read_warrant_bible()',
     '2022/07/17: 0.1.37 加入 tredis'
     '2022/08/01: 0.1.39 加入註解，把一些東西拆開來，以免每次mypylib都要載入一堆 module',
-    '2022/08/05: 0.1.40 繼續拆開一些東西 tredis'
+    '2022/08/05: 0.1.40 繼續拆開一些東西 tredis',
+    '2022/08/12: 0.1.41 Remove password and 加入 finmind',
 }
 
 
@@ -216,7 +217,7 @@ def get_stock_future_snapshot(filename='stock_future_snapshot.txt'):
     import shioaji as sj
 
     def login(id='H121933940',
-              password='123edcxzaqws',
+              password='123',
               ca_path="SinoPac.pfx",
               ca_password='H121933940',
               person_id='H121933940'):
