@@ -72,7 +72,9 @@ class Tredis(threading.Thread):
                     logger.info(f'redis_working_thread got msg: {data}')
 
                     if data == self.str_thread_exit_magic:
-                        break
+                        if data.split(' ')[1] == str(self):
+                            logger.info(f'{self} to exit')
+                            break
                     else:
                         function_send = getattr(self.redis_msg_sender, 'redis_msg_sender', None)
                         if function_send is not None and callable(function_send):
@@ -86,6 +88,7 @@ class Tredis(threading.Thread):
     @logger.catch()
     def stop(self):
         t = threading.current_thread()
+        self.r.publish(self.channel, f'{self.str_thread_exit_magic} {str(self)}')
         self.r.publish(self.channel, self.str_thread_exit_magic)
 
 
